MethodChannelFCllama class

An implementation of FCllamaPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFCllama()

Properties

eventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
onTokenStream → Stream<Map<Object?, dynamic>>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bench(double contextId, {required double pp, required double tg, required double pl, required double nr}) → Future<String?>
override
completion(double contextId, {required String prompt, List<List<double>>? logitBias, String grammar = "", double temperature = 0.8, int nThreads = 0, int nPredict = -1, int nProbs = 0, int penaltyLastN = 64, double penaltyRepeat = 1.0, double penaltyFreq = 0.0, double penaltyPresent = 0.0, double mirostat = 0.0, double mirostatTau = 5.0, double mirostatEta = 0.1, bool penalizeNl = false, int topK = 40, double topP = 0.95, double minP = 0.05, double typicalP = 1.0, double xtcThreshold = 0.0, double xtcProbability = 0.0, int seed = -1, List<String>? stop, bool ignoreEos = false, bool emitRealtimeCompletion = false}) → Future<Map<Object?, dynamic>?>
override
detokenize(double contextId, {required List<int> tokens}) → Future<String?>
override
getCpuInfo() → Future<Map<Object?, dynamic>?>
override
getFileSHA256(String filePath) → Future<String?>
override
getFormattedChat(double contextId, {required List<RoleContent> messages, String? chatTemplate}) → Future<String?>
override
initContext(String model, {int modelType = 1, bool embedding = false, int nCtx = 768, int nBatch = 768, int nThreads = 2, int nGpuLayers = 0, bool useMlock = true, bool useMmap = true, String lora = "", bool loraInitWithoutApply = false, double loraScaled = 1.0, double ropeFreqBase = 0.0, double ropeFreqScale = 0.0, bool emitLoadProgress = false}) → Future<Map<Object?, dynamic>?>
override
loadSession(double contextId, {required String path}) → Future<Map<Object?, dynamic>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseAllContexts() → Future<void>
override
releaseContext(double contextId) → Future<void>
override
saveSession(double contextId, {required String path, required double size}) → Future<int?>
override
stopCompletion(double contextId) → Future<void>
override
tokenize(double contextId, {required String text}) → Future<Map<Object?, dynamic>?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited